@@ -127,10 +127,16 @@ class Driver(object):
         for i in range(num):
             self.delete()
 
-    def get_ui_tree(self):
+    @property
+    def page_source(self):
         page_source = self.d.dump_hierarchy()
         logger.info(f'获取页面内容: \n{page_source}')
         return page_source
 
 
+# 初始化
+driver = Driver()
+d = driver.d
+
+
 
