@@ -223,3 +223,6 @@ class Driver(object):
         self.swipe(w / 2, start_percent * h, w / 2, end_percent * h)
 
 
+# 初始化
+driver = Driver()
+d = driver.d
