@@ -1,3 +1,5 @@
+import os
+
 import requests
 from selenium import webdriver
 from qrunner.utils.log import logger
@@ -34,11 +36,13 @@ class Driver(object):
 
         logger.info(f'启动webdriver')
         options = webdriver.ChromeOptions()
-        options.add_experimental_option('androidDeviceSerial', self.serial_no)
-        options.add_experimental_option('androidPackage', self.pkg_name)
-        options.add_experimental_option('androidUseRunningApp', True)
-        options.add_experimental_option('androidProcess', self.pkg_name)
-        self.d = webdriver.Chrome(options=options)
+        # options.add_experimental_option('androidDeviceSerial', self.serial_no)
+        # options.add_experimental_option('androidPackage', self.pkg_name)
+        # options.add_experimental_option('androidUseRunningApp', True)
+        # options.add_experimental_option('androidProcess', self.pkg_name)
+        exe_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), '../../libs/chromedriver', '91', 'chromedriver.exe')
+        logger.info(f'chromedriver路径: {exe_path}')
+        self.d = webdriver.Chrome(executable_path=exe_path, options=options)
         self.d.set_page_load_timeout(10)
 
     @relaunch
@@ -51,11 +55,6 @@ class Driver(object):
         logger.info(f'输入文本: {value}')
         driver.send_keys(value)
 
-    @relaunch
-    def switch_input(self):
-        logger.info('切换输入法')
-        driver.d.set_fastinput_ime(enable=False)
-
     @relaunch
     def screenshot(self, filename, timeout=3):
         driver.wait_shot(filename, timeout=timeout)
@@ -89,6 +88,9 @@ class Driver(object):
         self.d.execute_script(script, element)
 
 
+# 初始化
+driver = Driver()
+d = driver.d
 
 
 
