@@ -1,7 +1,5 @@
 import os.path
-import subprocess
 import sys
-from qrunner.utils.log import logger
 
 
 def init_parser_scaffold(subparsers):
@@ -14,43 +12,10 @@ def init_parser_scaffold(subparsers):
     return sub_parser_scaffold
 
 
-def init_parser_scaffold_ios(subparsers):
-    sub_parser_scaffold = subparsers.add_parser(
-        "start_ios_project", help="Create a ios project with template structure."
-    )
-    sub_parser_scaffold.add_argument(
-        "project_name", type=str, nargs="?", help="Specify new project name."
-    )
-    return sub_parser_scaffold
-
-
-def create_scaffold(platform, project_name):
+def create_scaffold(project_name):
     """ create scaffold with specified project name.
     """
 
-    # def show_tree(prj_name):
-    #     try:
-    #         print(f"\n$ tree {prj_name}")
-    #         subprocess.run(["tree", prj_name])
-    #         print("")
-    #     except FileNotFoundError:
-    #         logger.warning("tree command not exists, ignore.")
-
-    # if os.path.isdir(project_name):
-    #     logger.warning(
-    #         f"Project folder {project_name} exists, please specify a new project name."
-    #     )
-    #     show_tree(project_name)
-    #     return 1
-    # elif os.path.isfile(project_name):
-    #     logger.warning(
-    #         f"Project name {project_name} conflicts with existed file, please specify a new one."
-    #     )
-    #     return 1
-
-    # logger.info(f"Create new project: {project_name}")
-    # print(f"Project Root Dir: {os.path.join(os.getcwd(), project_name)}\n")
-
     def create_folder(path):
         os.makedirs(path)
         msg = f"created folder: {path}"
@@ -86,12 +51,9 @@ conf.set_name('app', 'pkg_url', args.pkg_url)
 pytest.main(['tests', '--reruns', '1 ', '-s', '-v', '--alluredir', 'allure-results',
              '--clean-alluredir', '--html=report.html', '--self-contained-html'])
 """
-    demo_conftest = ""
-    demo_page = ""
-    if platform == 'android':
-        demo_conftest = """
+    demo_conftest_adr = """
 import pytest
-from qrunner.core.android.element import driver, Element as E
+from qrunner.core.android.element import driver
 from qrunner.utils.log import logger
 from conf.config import conf
 
@@ -129,24 +91,11 @@ def init_case():
     logger.info('停止应用')
     driver.stop_app()
 """
-        demo_page = """
-from qrunner.core.android.element import Element, driver
-
-
-class HomePage:
-    bottom_peer = Element(rid='com.qizhidao.clientapp:id/icon2')
-    
-    def go_peer(self):
-        self.bottom_peer.click()
-        driver.allure_shot('查同行')
-"""
-    elif platform == 'ios':
-        demo_conftest = """
+    demo_conftest_ios = """
 import pytest
 from qrunner.utils.log import logger
 from conf.config import conf
-from qrunner.core.ios.element import driver, Element
-
+from qrunner.core.ios.element import driver
 
 # 安装应用
 @pytest.fixture(scope='session', autouse=True)
@@ -172,9 +121,6 @@ def init_case():
     # 启动应用
     logger.info('用例开始: 启动应用')
     driver.force_start_app()
-    element = Element(name='以后再说')
-    if element.exists(1):
-        element.click()
     yield
     # 截图
     logger.info('用例结束: 进行截图')
@@ -183,39 +129,153 @@ def init_case():
     logger.info('用例结束: 退出应用')
     driver.stop_app()
 """
-        demo_page = """
-from qrunner.core.ios.element import Element, driver
+
+    demo_conftest_web = """
+import pytest
+from qrunner.utils.log import logger
+from qrunner.core.web.driver import Driver
+
+# 用例的前置和后置操作
+@pytest.fixture(scope='function', autouse=True)
+def init_case():
+    # 启动应用
+    logger.info('用例开始: 初始化driver')
+    driver = Driver()
+    yield driver
+    # 截图
+    logger.info('用例结束: 进行截图')
+    driver.allure_shot('用例结束')
+    # 停止应用
+    logger.info('用例结束: 关闭浏览器')
+    driver.close()
+"""
+
+    demo_page_adr = """
+from qrunner.core.android.element import Element
+
+
+class HomePage:
+    bottom_peer = Element(rid='com.qizhidao.clientapp:id/icon2')
+    
+    def go_peer(self):
+        self.bottom_peer.click()
+"""
+    demo_page_ios = """
+from qrunner.core.ios.element import Element
 
 
 class HomePage:
     bottom_peer = Element(name='查同行', index=2)
+    
+    def go_peer(self):
+        self.bottom_peer.click()
+"""
+    demo_page_h5 = """
+from qrunner.core.h5.element import Element
+from selenium.webdriver.common.by import By
+from qrunner.core.android.element import Element
+
+
+class HomePage:
+    bottom_peer = Element(resourceId='com.qizhidao.clientapp:id/icon2')
+    patent_search = Element(rid='com.qizhidao.clientapp:id/iv_icon', index=1)
 
     def go_peer(self):
         self.bottom_peer.click()
-        driver.allure_shot('查同行')
+
+    def go_patent(self):
+        self.patent_search.click()
+
+
+class PatentPage:
+    def __init__(self, d):
+        self.d = d
+        self.search_input = Element(d, By.CLASS_NAME, 'h-b-content')
+    
+    def go_search(self):
+        self.search_input.click()
 """
 
-    demo_case = """
+    demo_page_web = """
+from qrunner.core.web.element import Element
+from selenium.webdriver.common.by import By
+
+
+class PatentPage:
+    def __init__(self, d):
+        self.d = d
+        self.url = 'https://patents-pre.qizhidao.com/'
+        self.search_input = Element(d, By.ID, 'driver-home-step1')
+    
+    def open_page(self):
+        self.d.get(self.url)
+
+    def go_search(self):
+        self.search_input.click()
+"""
+
+    demo_case_android = """
 import allure
-from pages.demo_page import HomePage
+from pages.android.demo_page import HomePage
 
 
 @allure.feature('首页信息流')
-@allure.story('金刚位')
 class TestPeerSearch:
     @allure.title('从首页信息流进入查同行')
     def test(self):
         HomePage().go_peer()
 """
 
-    ignore_content = "\n".join(
-        ["allure-results/*", "__pycache__/*", "*.pyc", "report.html", ".idea/*"]
-    )
+    demo_case_ios = """
+import allure
+from pages.ios.demo_page import HomePage
 
-    config_content = """
+
+@allure.feature('首页信息流')
+class TestPeerSearch:
+    @allure.title('从首页信息流进入查同行')
+    def test(self):
+        HomePage().go_peer()
+"""
+
+    demo_case_h5 = """
+import allure
+from qrunner.core.h5.driver import Driver
+from pages.h5.demo_page import HomePage, PatentPage
+
+
+@allure.feature('查专利')
+class TestPeerSearch:
+    def setup_method(self):
+        self.d = Driver()
+        self.home_page = HomePage()
+        self.patent_page = PatentPage(self.d)
+
+    @allure.title('点击顶部搜索框')
+    def test(self):
+        self.home_page.go_patent()
+        self.patent_page.go_search()
+"""
+    demo_case_web = """
+import allure
+from pages.web.demo_page import PatentPage
+
+
+@allure.feature('首页信息流')
+class TestPeerSearch:
+    @allure.title('从首页信息流进入查同行')
+    def test(self, driver):
+        self.patent_page = PatentPage(driver)
+        self.patent_page.open_page()
+        self.patent_page.go_search()
+"""
+
+    demo_require = """
+qrunner
+"""
+    demo_config = """
 [device]
 serial_no = 
-
 [app]
 need_install = no
 pkg_name = 
@@ -224,16 +284,12 @@ pkg_url =
     config_handle = """
 import os
 import configparser
-
 local_path = os.path.dirname(os.path.realpath(__file__))
-
-
 class Config:
     def __init__(self):
         self.conf_file_path = os.path.join(local_path, 'config.ini')
         self.cf = configparser.ConfigParser()
         self.cf.read(self.conf_file_path, encoding='utf-8')
-
     def get_name(self, module, key):
         if not self.cf.has_option(module, key):
             print('未找到该数据')
@@ -241,43 +297,83 @@ class Config:
         else:
             value = self.cf.get(module, key)
         return value
-
     def set_name(self, module, key, value):
         if not self.cf.has_section(module):
             self.cf.add_section(module)
         self.cf.set(module, key, value)
         with open(self.conf_file_path, 'w') as f:
             self.cf.write(f)
-
-
 # 初始化
 conf = Config()
 """
-
-    require_content = """
-qrunner
-"""
+    demo_ignore = "\n".join(
+        ["allure-results/*", "__pycache__/*", "*.pyc", "report.html", ".idea/*"]
+    )
 
     create_folder(project_name)
     create_folder(os.path.join(project_name, "tests"))
+    create_folder(os.path.join(project_name, "tests", "android"))
+    create_folder(os.path.join(project_name, "tests", "h5"))
+    create_folder(os.path.join(project_name, "tests", "web"))
+    create_folder(os.path.join(project_name, "tests", "ios"))
     create_folder(os.path.join(project_name, "pages"))
+    create_folder(os.path.join(project_name, "pages", 'android'))
+    create_folder(os.path.join(project_name, "pages", 'h5'))
+    create_folder(os.path.join(project_name, "pages", 'web'))
+    create_folder(os.path.join(project_name, "pages", "ios"))
     create_folder(os.path.join(project_name, "conf"))
 
     create_file(
-        os.path.join(project_name, "tests", "conftest.py"),
-        demo_conftest,
+        os.path.join(project_name, "tests", "android", "conftest.py"),
+        demo_conftest_adr,
     )
     create_file(
-        os.path.join(project_name, "tests", "test_demo.py"),
-        demo_case,
+        os.path.join(project_name, "tests", "h5", "conftest.py"),
+        demo_conftest_adr,
     )
     create_file(
-        os.path.join(project_name, "pages", "demo_page.py"),
-        demo_page,
+        os.path.join(project_name, "tests", "web", "conftest.py"),
+        demo_conftest_web,
+    )
+    create_file(
+        os.path.join(project_name, "tests", "ios", "conftest.py"),
+        demo_conftest_ios,
+    )
+    create_file(
+        os.path.join(project_name, "tests", "android", "test_demo.py"),
+        demo_case_android,
+    )
+    create_file(
+        os.path.join(project_name, "tests", "h5", "test_demo.py"),
+        demo_case_h5,
+    )
+    create_file(
+        os.path.join(project_name, "tests", "web", "test_demo.py"),
+        demo_case_web,
+    )
+    create_file(
+        os.path.join(project_name, "tests", "ios", "test_demo.py"),
+        demo_case_ios,
+    )
+    create_file(
+        os.path.join(project_name, "pages", "android", "demo_page.py"),
+        demo_page_adr,
+    )
+    create_file(
+        os.path.join(project_name, "pages", "h5", "demo_page.py"),
+        demo_page_h5,
+    )
+    create_file(
+        os.path.join(project_name, "pages", "web", "demo_page.py"),
+        demo_page_web,
+    )
+    create_file(
+        os.path.join(project_name, "pages", "ios", "demo_page.py"),
+        demo_page_ios,
     )
     create_file(
         os.path.join(project_name, "conf", "config.ini"),
-        config_content,
+        demo_config,
     )
     create_file(
         os.path.join(project_name, "conf", "config.py"),
@@ -289,11 +385,11 @@ qrunner
     )
     create_file(
         os.path.join(project_name, ".gitignore"),
-        ignore_content,
+        demo_ignore,
     )
     create_file(
         os.path.join(project_name, "requirements.txt"),
-        require_content,
+        demo_require,
     )
 
     # show_tree(project_name)
@@ -301,8 +397,5 @@ qrunner
 
 
 def main_scaffold(args):
-    sys.exit(create_scaffold('android', args.project_name))
+    sys.exit(create_scaffold(args.project_name))
 
-
-def main_scaffold_ios(args):
-    sys.exit(create_scaffold('ios', args.project_name))
