@@ -1,14 +1,10 @@
 import smtplib
-import time
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 from email.header import Header
 
 
 # 邮件通知
-from qrunner.utils.allure_data import get_allure_data
-
-
 class Mail:
     def __init__(self, host, user, password):
         self.host = host
@@ -16,12 +12,6 @@ class Mail:
         self.password = password
 
     def send_mail(self, mail_data, receivers):
-        """
-        参考：https://blog.csdn.net/fenglepeng/article/details/107005000
-        @param mail_data:
-        @param receivers:
-        @return:
-        """
         print(f'向{receivers}发送邮件...')
         # 创建一个带附件的实例
         message = MIMEMultipart()
@@ -56,28 +46,21 @@ class Mail:
         # 断开连接
         conn.quit()
 
-    def send_report(self, title, report_url, receiver_list):
-        allure_data = get_allure_data('allure-results')
-        total = allure_data.get('total')
-        fail = allure_data.get('fail')
-        passed = allure_data.get('passed')
-        rate = allure_data.get('rate')
-
-        # 邮件内容
-        title = f'{title}({time.strftime("%m-%d %H:%M")})'
-        body_str = '\n\n共 {0} 个用例，通过 {1} 个，失败 {2} 个，通过率 {3}%，详见: {4}'\
-            .format(total, passed, fail, rate, report_url)
-        msg_data = {
-            'title': title,
-            'body': body_str,
-            'file_path': None,
-            'file_name': None
-        }
-
-        # 发送邮件
-        self.send_mail(msg_data, receiver_list)
 
+# 初始化
+mail = Mail('smtphm.qiye.163.com', 'kang.yang@qizhidao.com', 'WzQzd2019')
 
 
+if __name__ == '__main__':
+    # 邮件内容
+    mail_data = {
+        'title': '测试邮件',
+        'body': '测试',
+        'file_path': None,
+        'file_name': None
+    }
+    # 收件人
+    receiver_list = ['kang.yang@qizhidao.com', 'kang.yang@qizhidao.com']
+    mail.send_mail(mail_data, receiver_list)
 
 
